<?php

namespace Drupal\conditional_message\Endpoint;

use Drupal\conditional_message\Entity\ConditionalMessage;

/**
 * Defines the endpoint where the data is exposed.
 */
class ConditionalMessageEndpoint {

  /**
   * Gathers and treats the data to be exposed.
   *
   * @return array
   *   A list of messages.
   */
  public function getEndpointData() {
    // Prepare the result data.
    $data = [];

    // Get all existing messages ids.
    $cmids = \Drupal::entityQuery('conditional_message')->execute();

    // Load each entity by id.
    $messages = ConditionalMessage::loadMultiple($cmids);

    // Foreach message, check the conditions.
    // TODO review the logic of all conditions and combinations.
    // In the backend (here) we check for the role conditions.
    // In the front end (JS) we check for session, path and content type.
    foreach ($messages as $cmid => $message) {
      // Set each field value accordingly.
      $conditions = $message->getConditions();

      // Check for conditions and expose in the endpoint.
      $data[$cmid]['role'] = TRUE;
      foreach ($conditions as $condition) {
        switch ($condition) {
          case 'close':
            $data[$cmid]['close'] = TRUE;
            break;

          case 'role':
            // For now 'role' is the only backend check.
            $data[$cmid]['role'] = FALSE;
            $user = \Drupal::currentUser();
            $selected_roles = $message->getRoleOptions();
            $user_roles = $user->getRoles();
            foreach ($selected_roles as $selected_role) {
              foreach ($user_roles as $role_key => $role_value) {
                if ($selected_role === $role_value) {
                  $data[$cmid]['role'] = TRUE;
                  continue 2;
                }
              }
            }
            break;

          case 'path':
            $raw_selected_paths = $message->getPathOptions();
            $data[$cmid]['paths'] = array_map('trim', $raw_selected_paths);
            break;

          case 'content_type':
            $selected_types = $message->getContentTypeOptions();
            $data[$cmid]['types'] = array_filter($selected_types);
            break;
        }
      }

      // Determine if the message should be displayed or not.
      if ($data[$cmid]['role']) {
        $data[$cmid]['display'] = TRUE;
      }
    }

    return $data;
  }

}
